@@ -2,9 +2,10 @@ use actix_web_validator::{error::DeserializeErrors, Error};
 use serde::Deserialize;
 
 #[derive(Deserialize)]
+#[allow(dead_code)]
 struct Query {
-    pub test: i32,
-    pub value: i32,
+    test: i32,
+    value: i32,
 }
 
 #[test]
